<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Password;
use App\Models\User;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Http;


class AuthController extends Controller
{

    public function websiteLogin(Request $request)
    {
        if ($request->isMethod('post')) {
            $credentials = $request->validate([
                'email' => 'required|email|regex:/^[\w\.-]+@[\w\.-]+\.\w{2,}$/',
                'password' => 'required',
            ]);

            $remember = $request->has('remember'); // Check if "Remember Me" is checked

            if (Auth::attempt($credentials, $remember)) {
                $request->session()->regenerate();
                return redirect()->route('frontend.index');
            }

            return back()->withErrors(['email' => 'Please enter correct credentials'])->withInput();
        }

        return view('frontend.login');
    }

    public function websiteRegister(Request $request)
    {
        if ($request->isMethod('post')) {
            $request->validate([
                'name' => 'required|string|max:255',
                'email' => 'required|email|unique:users|max:255|regex:/^[\w\.-]+@[\w\.-]+\.\w{2,}$/',
                'phone' => 'required',
                'password' => 'required|min:8|confirmed',
                'password_confirmation' => 'required|min:8',
                'location' => 'required',
                'vehicle_name' => 'required'
            ]);

            try {

                DB::beginTransaction();

                $city = $this->getCityFromCoordinates($request->longitude, $request->latitude);

                $user = User::create([
                    'name' => $request->name,
                    'email' => $request->email,
                    'phone' => $request->phone,
                    'password' => Hash::make($request->password),
                    'location' => $request->location,
                    'vehicle_name' => $request->vehicle_name,
                    'longitude' => $request->longitude,
                    'latitude' => $request->latitude,
                    'city' => $city,
                    'status' => 1,
                    'is_approved' => 1,
                    'roles' => 3,
                ]);

                DB::commit();
                return redirect()->route('frontend.login');
            } catch (Exception $e) {
                DB::rollback();
                return redirect()->back()->with('error', 'Something went wrong');
            }
        }

        return view('frontend.register');
    }

    public function vendorRegister(Request $request)
    {
        if ($request->isMethod('post')) {

            // Validate the input data
            $validated = $request->validate([
                'name' => 'required|string|max:255',
                'email' => 'required|email|unique:users,email',
                'phone' => 'required|numeric',
                'location' => 'required|string',
                'document' => 'nullable|mimes:jpg,jpeg,png,pdf,docx|max:2048',
                'latitude' => 'nullable|numeric',
                'longitude' => 'nullable|numeric',
                'vehicle_name' => 'required'
            ]);

            try {

                DB::beginTransaction();

                // Get city from coordinates (implement this method)
                $city = $this->getCityFromCoordinates($request->latitude, $request->longitude);

                // Handle document upload
                if ($request->hasFile('document')) {
                    $validated['document'] = $request->file('document')->store('documents', 'public');
                }

                $validated['vehicle_name'] = $request->vehicle_name;

                // Additional fields
                $validated['roles'] = 2; // Assuming 2 is the role for vendors
                $validated['city'] = $city;
                $validated['status'] = 1;
                $validated['is_approved'] = 0;

                // Create the vendor
                User::create($validated);

                DB::commit();

                return redirect()->route('frontend.index')->with('success', 'Vendor registered successfully!');
            } catch (Exception $e) {
                dd($e->getMessage());
                return redirect()->back()->with('error', 'Server error!')->withInput();
            }
        } else {
            return view('frontend.vendor_register');
        }
    }

    public function login(Request $request)
    {
        if ($request->isMethod('post')) {
            $credentials = $request->validate([
                'email' => 'required|email|regex:/^[\w\.-]+@[\w\.-]+\.\w{2,}$/',
                'password' => 'required',
            ]);

            $remember = $request->has('remember'); // Check if "Remember Me" is checked

            if (Auth::attempt($credentials, $remember)) {
                $request->session()->regenerate();
                return redirect()->route('backend.dashboard');
            }

            return back()->withErrors(['email' => 'Please enter correct credentials'])->withInput();
        }

        return view('backend.login');
    }

    /**
     * Show Forgot Password Form
     */
    public function showForgotPasswordForm()
    {
        return view('frontend.forgot_password');
    }

    /**
     * Handle Forgot Password Request
     */
    public function sendResetLink(Request $request)
    {
        $request->validate([
            'email' => 'required|email|exists:users,email',
        ]);

        $status = Password::sendResetLink($request->only('email'));

        return $status === Password::RESET_LINK_SENT
            ? back()->with(['status' => __($status)])
            : back()->withErrors(['email' => __($status)]);
    }

    /**
     * Show Reset Password Form
     */
    public function showResetPasswordForm($token)
    {
        return view('frontend.reset_password', ['token' => $token]);
    }

    /**
     * Handle Reset Password Request
     */
    public function resetPassword(Request $request)
    {
        $request->validate([
            'email' => 'required|email|exists:users,email',
            'password' => 'required|min:6|confirmed',
            'token' => 'required',
        ]);

        $status = Password::reset(
            $request->only('email', 'password', 'password_confirmation', 'token'),
            function (User $user, string $password) {
                $user->forceFill([
                    'password' => Hash::make($password),
                ])->save();

                Auth::login($user);
            }
        );

        return $status === Password::PASSWORD_RESET
            ? redirect()->route('backend.dashboard')->with('status', __($status))
            : back()->withErrors(['email' => [__($status)]]);
    }

    public function getCityFromCoordinates($latitude, $longitude)
    {
        $apiKey = env('GOOGLE_PLACES_API_KEY'); // Store API key in .env
        $url = "https://maps.googleapis.com/maps/api/geocode/json?latlng={$latitude},{$longitude}&key={$apiKey}";

        $response = Http::get($url);
        $data = $response->json();


        if ($data['status'] == 'OK') {
            foreach ($data['results'][0]['address_components'] as $component) {
                if (in_array('locality', $component['types'])) {
                    return $component['long_name']; // Return city name
                }
            }
        }

        return null; // Default if city not found
    }

    public function logout(Request $request)
    {
        Auth::logout(); // Logout the user

        $request->session()->invalidate(); // Invalidate the session
        $request->session()->regenerateToken(); // Regenerate CSRF token

        return redirect()->route('backend.login'); // Redirect to login page
    }

    public function websiteLogout(Request $request)
    {
        Auth::logout(); // Logout the user

        $request->session()->invalidate(); // Invalidate the session
        $request->session()->regenerateToken(); // Regenerate CSRF token

        return redirect()->route('frontend.index'); // Redirect to login page
    }
}
