<?php

namespace App\Livewire;

use Livewire\Component;
use Livewire\WithFileUploads;
use App\Models\User;
use Exception;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Http;


class EditVendor extends Component
{
    use WithFileUploads;

    public $vendor, $image, $name, $email, $phone, $password, $password_confirmation, $location, $document, $longitude, $latitude, $city;
    public $existingImage, $existingDocument;

    public function getCityFromCoordinates($latitude, $longitude)
    {
        $apiKey = env('GOOGLE_PLACES_API_KEY'); // Store API key in .env
        $url = "https://maps.googleapis.com/maps/api/geocode/json?latlng={$latitude},{$longitude}&key={$apiKey}";

        $response = Http::get($url);
        $data = $response->json();

        if ($data['status'] == 'OK') {
            foreach ($data['results'][0]['address_components'] as $component) {
                if (in_array('locality', $component['types'])) {
                    return $component['long_name']; // Return city name
                }
            }
        }

        return null; // Default if city not found
    }

    public function mount($id)
    {
        $this->vendor = User::findOrFail($id);
        $this->name = $this->vendor->name;
        $this->email = $this->vendor->email;
        $this->phone = $this->vendor->phone;
        $this->location = $this->vendor->location;
        $this->existingImage = $this->vendor->image;
        $this->existingDocument = $this->vendor->document;
        $this->longitude = $this->vendor->longitude;
        $this->latitude = $this->vendor->latitude;
    }

    public function update()
    {
        $validated = $this->validate([
            'image' => 'nullable|mimes:jpg,jpeg,png|max:2048',
            'name' => 'required',
            'email' => 'required|email|unique:users,email,' . $this->vendor->id,
            'phone' => 'required|numeric',
            'password' => 'nullable|min:6|same:password_confirmation',
            'password_confirmation' => 'nullable',
            'location' => 'required',
            'document' => 'nullable|mimes:jpg,jpeg,png,pdf,docx|max:2048',
        ]);

        try {
            // Handle profile image upload
            if ($this->image) {
                $validated['image'] = $this->image->store('vendor_images', 'public');
            } else {
                $validated['image'] = $this->existingImage;
            }

            // Handle document upload
            if ($this->document) {
                $validated['document'] = $this->document->store('documents', 'public');
            } else {
                $validated['document'] = $this->existingDocument;
            }

            // Hash password if provided
            if ($this->password) {
                $validated['password'] = Hash::make($this->password);
            } else {
                unset($validated['password']);
            }

            $validated['longitude'] = $this->longitude;
            $validated['latitude'] = $this->latitude;
            $validated['is_approved'] = 1;

            // Update vendor
            $this->vendor->update($validated);

            return redirect()->route('backend.vendors');
        } catch (Exception $e) {
            return redirect()->back()->with('errors', 'Server error!')->withInput();
        }
    }

    public function render()
    {
        return view('livewire.edit-vendor');
    }
}
