<?php

namespace App\Livewire;

use Livewire\Component;
use Livewire\WithPagination;
use App\Models\User;
use App\Models\Lead;
use App\Models\VendorJob;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Http;


class ListJobs extends Component
{
    use WithPagination;

    protected $paginationTheme = 'bootstrap';

    public $search = '';
    public $startDate;
    public $endDate;
    public $tab = 'requested'; // Default tab is Pending
    public $vendorsList = [];
    public $selectedJobId;
    public $jobAssignedTo;
    public $assignedVendorId;

    public function updatingSearch()
    {
        $this->resetPage();
    }

    public function updatingStartDate()
    {
        $this->resetPage();
    }

    public function updatingEndDate()
    {
        $this->resetPage();
    }

    public function setTab($tab)
    {
        $this->tab = $tab;
        $this->resetPage();
    }

    public function deleteJob($id)
    {
        $lead = Lead::where('id', $id)->delete();
        $job = VendorJob::where('lead_id', $id)->delete();

        session()->flash('success', 'Job deleted successfully!');
        return redirect()->route('backend.jobs'); // Change as needed
    }

    public function getCityFromCoordinates($latitude, $longitude)
    {
        $apiKey = env('GOOGLE_MAPS_API_KEY'); // Store API key in .env
        $url = "https://maps.googleapis.com/maps/api/geocode/json?latlng={$latitude},{$longitude}&key={$apiKey}";

        $response = Http::get($url);
        $data = $response->json();

        if ($data['status'] == 'OK') {
            foreach ($data['results'][0]['address_components'] as $component) {
                if (in_array('locality', $component['types'])) {
                    return $component['long_name']; // Return city name
                }
            }
        }

        return null; // Default if city not found
    }

    public function getNearbyVendors($longitude, $latitude)
    {
         $city = $this->getCityFromCoordinates($latitude, $longitude);
         return VendorJob::where('city', $city)->get();
    }

    public function openAssignModal($jobId)
    {

        $this->selectedJobId = $jobId;

        $getJob = VendorJob::with('vendor')->where('id', $jobId)->first();

        if(!empty($getJob->vendor))
        {
            $this->jobAssignedTo = $getJob->vendor->name;
            $this->assignedVendorId = $getJob->vendor->id;
        }
        else
        {
            $this->jobAssignedTo = '';
            $this->assignedVendorId = '';
        }

        $this->vendorsList = User::where('roles', 2)->where('is_approved', 1)->get();
    }

    public function assignVendorToJob($vendorId)
    {
        $job = VendorJob::findOrFail($this->selectedJobId);
        $job->vendor_id = $vendorId;
        $job->save();

        session()->flash('success', 'Vendor assigned to job successfully!');
        $this->dispatch('closeModal');
    }

    public function render()
    {
        $query = VendorJob::with(['lead', 'vendor']);

        if ($this->tab == 'requested') {
            $query->where('status', 'pending')->where('is_approved', 0);
        } else if ($this->tab == 'pending') {
            $query->where('status', 'pending')->where('is_approved', 1);
        } elseif ($this->tab == 'in_progress') {
            $query->where('status', 'in_progress')->where('is_approved', 1);
        } else {
            $query->where('status', 'completed')->where('is_approved', 1);
        }

        // Apply search filter
        $query->when($this->search, function ($query) {
            $query->whereHas('lead', function ($q) {
                $q->where('name', 'like', '%' . $this->search . '%');
            })->orWhereHas('vendor', function ($q) {
                $q->where('name', 'like', '%' . $this->search . '%');
            });
        });

        // Apply date filter
        $query->when($this->startDate && $this->endDate, function ($query) {
            $query->whereBetween(DB::raw('DATE(created_at)'), [$this->startDate, $this->endDate]);
        });

        // Assign the result back to $jobs
        $jobs = $query->orderby('id', 'desc')->paginate(25);

        return view('livewire.list-jobs', ['jobs' => $jobs]);
    }
}
